@@ -1,21 +1,8 @@
 /*
- *  Copyright 2016 Marco Martin <mart@kde.org>
- *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License as
- *   published by the Free Software Foundation; either version 2, or
- *   (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details
- *
- *   You should have received a copy of the GNU Library General Public
- *   License along with this program; if not, write to the
- *   Free Software Foundation, Inc.,
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2016 Marco Martin <mart@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #ifndef SCREENPOOL_H
 #define SCREENPOOL_H
@@ -54,13 +41,12 @@ public:
 
     void insertScreenMapping(const QString &connector);
     void reload(QString path);
+    void removeScreens(const Latte::Data::ScreensTable &obsoleteScreens);
 
     int id(const QString &connector) const;
 
     QString connector(int id) const;
 
-    QString reportHtml(const QList<int> &assignedScreens) const;
-
     QScreen *screenForId(int id);
 
     Latte::Data::ScreensTable screensTable();
