@@ -62,10 +62,10 @@
 
 namespace Latte {
 
-//! both alwaysVisible and byPassWM are passed through corona because
+//! both alwaysVisible and byPassWMX11 are passed through corona because
 //! during the view window creation containment hasn't been set, but these variables
 //! are needed in order for window flags to be set correctly
-View::View(Plasma::Corona *corona, QScreen *targetScreen, bool byPassWM)
+View::View(Plasma::Corona *corona, QScreen *targetScreen, bool byPassX11WM)
     : PlasmaQuick::ContainmentView(corona),
       m_contextMenu(new ViewPart::ContextMenu(this)),
       m_effects(new ViewPart::Effects(this)),
@@ -90,8 +90,10 @@ View::View(Plasma::Corona *corona, QScreen *targetScreen, bool byPassWM)
             | Qt::NoDropShadowWindowHint
             | Qt::WindowDoesNotAcceptFocus;
 
-    if (byPassWM) {
+    if (byPassX11WM) {
         setFlags(flags | Qt::BypassWindowManagerHint);
+        //! needs to be set early enough
+        m_byPassWM = byPassX11WM;
     } else {
         setFlags(flags);
     }
@@ -106,9 +108,10 @@ View::View(Plasma::Corona *corona, QScreen *targetScreen, bool byPassWM)
     connect(&m_releaseGrabTimer, &QTimer::timeout, this, &View::releaseGrab);
 
     connect(m_contextMenu, &ViewPart::ContextMenu::menuChanged, this, &View::updateTransientWindowsTracking);
+    connect(m_interface, &ViewPart::ContainmentInterface::hasExpandedAppletChanged, this, &View::updateTransientWindowsTracking);
 
     connect(this, &View::containmentChanged
-            , this, [ &, byPassWM]() {
+            , this, [ &, byPassX11WM]() {
         qDebug() << "dock view c++ containment changed 1...";
 
         if (!this->containment())
@@ -122,7 +125,7 @@ View::View(Plasma::Corona *corona, QScreen *targetScreen, bool byPassWM)
         restoreConfig();
 
         //! Afterwards override that values in case during creation something different is needed
-        setByPassWM(byPassWM);
+        setByPassWM(byPassX11WM);
 
         //! Check the screen assigned to this dock
         reconsiderScreen();
@@ -639,6 +642,15 @@ void View::updateAbsoluteGeometry(bool bypassChecks)
         }
     }
 
+    if (KWindowSystem::isPlatformX11() && devicePixelRatio() != 1.0) {
+        //!Fix for X11 Global Scale, I dont think this could be pixel perfect accurate
+        auto factor = devicePixelRatio();
+        absGeometry = QRect(qRound(absGeometry.x() * factor),
+                            qRound(absGeometry.y() * factor),
+                            qRound(absGeometry.width() * factor),
+                            qRound(absGeometry.height() * factor));
+    }
+
     if (m_absoluteGeometry == absGeometry && !bypassChecks) {
         return;
     }
@@ -662,16 +674,22 @@ void View::statusChanged(Plasma::Types::ItemStatus status)
         return;
     }
 
-    if (status == Plasma::Types::NeedsAttentionStatus) {
+    //! Fix for #443236, following setFlags(...) need to be added at all three cases
+    //! but initViewFlags() should be called afterwards because setFlags(...) breaks
+    //! the Dock window default behavior under x11
+    if (status == Plasma::Types::NeedsAttentionStatus || status == Plasma::Types::RequiresAttentionStatus) {
         m_visibility->addBlockHidingEvent(BLOCKHIDINGNEEDSATTENTIONTYPE);
+        setFlags(flags() | Qt::WindowDoesNotAcceptFocus);
         m_visibility->initViewFlags();
     } else if (status == Plasma::Types::AcceptingInputStatus) {
         m_visibility->removeBlockHidingEvent(BLOCKHIDINGNEEDSATTENTIONTYPE);
         setFlags(flags() & ~Qt::WindowDoesNotAcceptFocus);
+        m_visibility->initViewFlags();
         KWindowSystem::forceActiveWindow(winId());
     } else {
         updateTransientWindowsTracking();
         m_visibility->removeBlockHidingEvent(BLOCKHIDINGNEEDSATTENTIONTYPE);
+        setFlags(flags() | Qt::WindowDoesNotAcceptFocus);
         m_visibility->initViewFlags();
     }
 }
@@ -702,6 +720,10 @@ void View::removeTransientWindow(const bool &visible)
         disconnect(window, &QWindow::visibleChanged, this, &View::removeTransientWindow);
         m_transientWindows.removeAll(window);
 
+        if (m_visibility->hasBlockHidingEvent(Latte::GlobalShortcuts::SHORTCUTBLOCKHIDINGTYPE)) {
+            m_visibility->removeBlockHidingEvent(Latte::GlobalShortcuts::SHORTCUTBLOCKHIDINGTYPE);
+        }
+
         updateTransientWindowsTracking();
     }
 }
@@ -709,11 +731,9 @@ void View::removeTransientWindow(const bool &visible)
 void View::updateTransientWindowsTracking()
 {
     for(QWindow *window: qApp->topLevelWindows()) {
-        if (window->transientParent() == this){
-            if (window->isVisible()) {
-                addTransientWindow(window);
-                break;
-            }
+        if (window->transientParent() == this && window->isVisible()){
+            addTransientWindow(window);
+            break;
         }
     }
 }
