@@ -128,7 +128,7 @@ class View : public PlasmaQuick::ContainmentView
     Q_PROPERTY(QRect screenGeometry READ screenGeometry NOTIFY screenGeometryChanged)
 
 public:
-    View(Plasma::Corona *corona, QScreen *targetScreen = nullptr, bool byPassWM = false);
+    View(Plasma::Corona *corona, QScreen *targetScreen = nullptr, bool byPassX11WM = false);
     virtual ~View();
 
     void init(Plasma::Containment *plasma_containment = nullptr);
